open.20.fsguruh@xoxy.net 83dedd83bc changed ISR masking back to old solution; throttle rescale bugfix with limits changed;
This change make ISR masking for 10msec call back to the old solution.
Bugfix for throttle time calculation if limits are changed.
Noticed my optimized recalculation routine was wrong.
Now I changed it and recalculation is done on 32bit basis which cause 16bytes more flash.
I also noticed the original version (in trunk) just does recalculation of 10 base. That means for full throttle range there would be only 10 steps noticed if limits are changed. That leads to a very unpresise calculation if your throttle limit do not match these steps.
I can do something similar but this time only with 8 steps but save 16bytes flash.
What's your opinion.
2013-02-24 14:11:12 +00:00
2012-11-15 02:10:48 +00:00
2012-05-07 18:35:48 +00:00
2012-04-21 17:52:06 +00:00
S
Description
No description provided
GPL-2.0
400 MiB
Languages
C 71.9%
C++ 25.4%
Python 0.9%
CMake 0.6%
Shell 0.3%
Other 0.7%